# pyLoDStorage
python List of Dict (Table) Storage library

| | |
| :--- | :--- |
| **PyPi** | [![PyPI Status](https://img.shields.io/pypi/v/pyLodStorage.svg)](https://pypi.python.org/pypi/pyLodStorage/) [![License](https://img.shields.io/github/license/WolfgangFahl/pyLoDStorage.svg)](https://www.apache.org/licenses/LICENSE-2.0) [![pypi](https://img.shields.io/pypi/pyversions/pyLodStorage)](https://pypi.org/project/pyLodStorage/) [![format](https://img.shields.io/pypi/format/pyLodStorage)](https://pypi.org/project/pyLodStorage/) [![downloads](https://img.shields.io/pypi/dd/pyLodStorage)](https://pypi.org/project/pyLodStorage/) |
| **GitHub** | [![Github Actions Build](https://github.com/WolfgangFahl/pyLoDStorage/actions/workflows/build.yml/badge.svg)](https://github.com/WolfgangFahl/pyLoDStorage/actions/workflows/build.yml) [![Release](https://img.shields.io/github/v/release/WolfgangFahl/pyLoDStorage)](https://github.com/WolfgangFahl/pyLoDStorage/releases) [![Contributors](https://img.shields.io/github/contributors/WolfgangFahl/pyLoDStorage)](https://github.com/WolfgangFahl/pyLoDStorage/graphs/contributors) [![Last Commit](https://img.shields.io/github/last-commit/WolfgangFahl/pyLoDStorage)](https://github.com/WolfgangFahl/pyLoDStorage/commits/) [![GitHub issues](https://img.shields.io/github/issues/WolfgangFahl/pyLoDStorage.svg)](https://github.com/WolfgangFahl/pyLoDStorage/issues) [![GitHub closed issues](https://img.shields.io/github/issues-closed/WolfgangFahl/pyLoDStorage.svg)](https://github.com/WolfgangFahl/pyLoDStorage/issues/?q=is%3Aissue+is%3Aclosed) |
| **Code** | [![style-black](https://img.shields.io/badge/%20style-black-000000.svg)](https://github.com/psf/black) [![imports-isort](https://img.shields.io/badge/%20imports-isort-%231674b1)](https://pycqa.github.io/isort/) |
| **Docs** | [![API Docs](https://img.shields.io/badge/API-Documentation-blue)](https://WolfgangFahl.github.io/pyLoDStorage/) [![formatter-docformatter](https://img.shields.io/badge/%20formatter-docformatter-fedcba.svg)](https://github.com/PyCQA/docformatter) [![style-google](https://img.shields.io/badge/%20style-google-3666d6.svg)](https://google.github.io/styleguide/pyguide.html#s3.8-comments-and-docstrings) |

What it is
==========
pyLoDStorage allows to store table like data (List of Dicts) via

- Sqlite3
- JSON
- SPARQL

Installation
============
```bash
pip install pylodstorage
```

Get Sources
===========
```bash
git clone https://github.com/WolfgangFahl/pyLoDStorage
cd pyLodStorage
scripts/install
```

Testing
=======
```bash
scripts/test
```

Usage
=====
see [test cases](https://github.com/WolfgangFahl/pyLoDStorage/tree/master/tests)

## Documentation
[Wiki](http://wiki.bitplan.com/index.php/PyLoDStorage)

### Authors
* [Wolfgang Fahl](http://www.bitplan.com/Wolfgang_Fahl)
* [Tim Holzheim](https://www.semantic-mediawiki.org/wiki/Tim_Holzheim)
